"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        _log('Initializing with languages:', initialLanguages.map(l => l.name));
        _log('Initializing with themes:', initialThemes.map(t => t.name));
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }
        const defaultTheme = initialThemes[0];
        if (!defaultTheme || !defaultTheme.name) {
          throw new Error('Invalid theme format');
        }
        _log('Theme details:', {
          name: defaultTheme.name,
          type: defaultTheme.type,
          tokenColors: defaultTheme.tokenColors?.length,
          settings: defaultTheme.settings?.length,
          colors: Object.keys(defaultTheme.colors || {}).length
        });
        const engine = createJavaScriptRegexEngine({
          forgiving: true,
          cache: new Map()
        });
        _log('Created regex engine');

        // Create a complete theme object
        const processedTheme = {
          name: defaultTheme.name,
          type: defaultTheme.type || 'dark',
          colors: defaultTheme.colors,
          // Important: Include both tokenColors and settings
          tokenColors: defaultTheme.tokenColors || [],
          settings: defaultTheme.settings || defaultTheme.tokenColors || []
        };
        _log('Processed theme:', {
          name: processedTheme.name,
          tokenColors: processedTheme.tokenColors?.length,
          settings: processedTheme.settings?.length
        });
        const highlighterInstance = await createHighlighterCore({
          themes: [processedTheme],
          langs: initialLanguages,
          engine
        });

        // Test tokenization with specific scope
        try {
          const testTokens = highlighterInstance.codeToTokens('const test = "hello"', {
            lang: 'typescript',
            theme: processedTheme.name,
            includeExplanation: true
          });
          _log('Test tokenization with scopes:', testTokens);
        } catch (e) {
          _log('Test tokenization failed:', e);
        }
        _log('Highlighter core created');

        // Validate languages were loaded
        const loadedLangs = highlighterInstance.getLoadedLanguages();
        _log('Loaded languages:', loadedLangs);
        if (loadedLangs.length === 0) {
          throw new Error('No languages were loaded');
        }

        // Set and validate theme
        const themeName = defaultTheme.name;
        highlighterInstance.setTheme(themeName);
        const loadedThemes = highlighterInstance.getLoadedThemes();
        _log('Loaded themes:', loadedThemes);
        if (!loadedThemes.includes(themeName)) {
          throw new Error(`Theme ${themeName} was not properly loaded`);
        }

        // Test tokenization
        try {
          const testTokens = highlighterInstance.codeToTokens('const test = "hello"', {
            lang: loadedLangs[0],
            theme: themeName
          });
          _log('Test tokenization result:', {
            success: true,
            tokenCount: testTokens.tokens.flat().length,
            firstToken: testTokens.tokens[0]?.[0]
          });
        } catch (e) {
          _log('Test tokenization failed:', e);
        }
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map